# Transmission-rpc Readme

this project is forked from https://bitbucket.org/blueluna/transmissionrpc/overview

## Introduction

`transmission-rpc` is a python module implementing the json-rpc client protocol for the BitTorrent client Transmission.

## Requirements

transmission_rpc requires:

* Python >= 3.4
* requests

## Install

### install from pypi

```bash
$ pip install transmission-rpc
```

### install from source

```bash
$ pip install https://github.com/Trim21/transmission-rpc/tarball/master
```

NOTE: You might need administrator privileges to install python modules.

<!-- The setup program will take care of the simple json requirement. -->

## Documents

<https://transmission-rpc.readthedocs.io/en/latest/>

## Break change

## Developer

transmission-rpc is hosted by GitHub at [github.com/Trim21/transmission-rpc](https://github.com/Trim21/transmission-rpc)

`transmission-rpc` is licensed under the MIT license.

Copyright (c) 2018 Trim21.
Copyright (c) 2008-2014 Erik Svensson
